==> nextcloud-22.2.8.tgz: nextcloud/apps/theming/l10n/tr.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ön izleme yükleniyor …",
    "Admin" : "Yönetici",
    "Saved" : "Kaydedildi",
    "a safe home for all your data" : "verileriniz için güvenli bir barınak",
    "Name cannot be empty" : "Ad boş olamaz",
    "The given name is too long" : "Belirtilen ad çok uzun",
    "The given web address is too long" : "Belirtilen web adresi çok uzun",
    "The given web address is not a valid URL" : "Belirtilen web adresi geçersiz",
    "The given legal notice address is too long" : "Belirtilen yasal bildirim adresi çok uzun",
    "The given legal notice address is not a valid URL" : "Belirtilen yasal bildirim adresi geçersiz",
    "The given privacy policy address is too long" : "Belirtilen kişisel gizliliğin korunması ilkesi adresi çok uzun",
    "The given privacy policy address is not a valid URL" : "Belirtilen gizlilik ilkesi adresi geçersiz",
    "The given slogan is too long" : "Belirtilen slogan çok uzun",
    "The given color is invalid" : "Belirtilen renk geçersiz",
    "The file was uploaded" : "Dosya yüklendi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklenen dosya php.ini dosyasındaki yüklenebilecek dosya boyutunu belirten upload_max_filesize değişkeninin değerini aşıyor",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenen dosya HTML formundaki yüklenebilecek dosya boyutunu belirten MAX_FILE_SIZE değişkeninin değerini aşıyor",
    "The file was only partially uploaded" : "Dosyanın yalnızca bir bölümü yüklendi",
    "No file was uploaded" : "Herhangi bir dosya yüklenmedi",
    "Missing a temporary folder" : "Geçici klasör bulunamadı",
    "Could not write file to disk" : "Dosya diske yazılamadı",
    "A PHP extension stopped the file upload" : "Bir PHP eklentisi dosyanın yüklenmesini engelledi",
    "No file uploaded" : "Henüz bir dosya yüklenmemiş",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Zaten özel bir tema kullanıyorsunuz. Tema uygulaması ayarları bu değer ile değiştirilebilir.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Görünüm ve erişilebilirlik",
    "Dark theme with high contrast mode" : "Koyu tema ve yüksek renk karşıtlığı kipi",
    "Enable dark high contrast mode" : "Koyu yüksek renk karşıtlığı kipi kullanılsın",
    "Similar to the high contrast mode, but with dark colours." : "Yüksek renk karşıtlığı kipine benzer ancak koyu renkleri kullanır.",
    "Dark theme" : "Koyu tema",
    "Enable dark theme" : "Koyu tema kullanılsın",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Koyu tema genel aydınlık ve parlaklığı azaltarak gözlerinizi dinlendirir.",
    "System default theme" : "Varsayılan sistem teması",
    "Enable the system default" : "Sistem varsayılanı kullanılsın",
    "Using the default system appearance." : "Varsayılan sistem görünümü kullanılıyor.",
    "Dyslexia font" : "Disleksik yazı türü",
    "Enable dyslexia font" : "Disleksik yazı türü kullanılsın",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic, disleksi nedeniyle sık karşılaşılan sorunları aşmak için geliştirilmiş ücretsiz bir yazı türüdür.",
    "High contrast mode" : "Yüksek renk karşıtlığı kipi",
    "Enable high contrast mode" : "Yüksek renk karşıtlığı kipi kullanılsın",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Yüksek renk karşıtlığı kipi gezinmeyi kolaylaştırır. Görsel kalite azalır ancak netlik artar.",
    "Light theme" : "Açık tema",
    "Enable the default light theme" : "Varsayılan açık tema kullanılsın",
    "The default light appearance." : "Varsayılan açık renkli görünüm.",
    "Legal notice" : "Yasal bildirim",
    "Privacy policy" : "Kişisel gizliliğin korunması ilkesi",
    "Adjust the Nextcloud theme" : "Nextcloud temasını ayarla",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uygulamalarımızı herkesin kullanabilmesini çok önemsiyoruz. Web standartlarını izleyerek, işlemlerin fare olmadan da yapılabilmesini ve ekran okuyucular gibi yardımcı yazılımların kullanılabilmesini sağlıyoruz. AAA düzeyinde yüksek renk karşıtlığı teması ile AA düzeyinde {guidelines}Web İçeriği Erişilebilirlik Kuralları{linkend} 2.1 ile uyumlu olmayı amaçladık.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Bir sorunla karşılaşırsanız, bunları {issuetracker}sorun izleyicimiz{linkend} üzerinden bildirmekten çekinmeyin. Katkıda bulunmak istiyorsanız {designteam}tasarım ekibimize{linkend} katılın!",
    "Theme selection is enforced" : "Tema seçimi zorunludur",
    "Open documentation" : "Belgeleri aç",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Temalar kullandığınız kopyanın ve desteklenen istemcilerin genel görünümün kolayca değiştirilmesini sağlar. Tüm kullanıcılara görüntülenir.",
    "Name" : "Ad",
    "Reset to default" : "Varsayılanlara dön",
    "Web link" : "Web bağlantısı",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Renk",
    "Logo" : "Logo",
    "Upload new logo" : "Yeni logo yükle",
    "Login image" : "Oturum açma görseli",
    "Upload new login background" : "Yeni oturum açma arka planı yükle",
    "Remove background image" : "Arka plan görselini kaldır",
    "Advanced options" : "Gelişmiş ayarlar",
    "Legal notice link" : "Yasal bildirim bağlantısı",
    "Privacy policy link" : "Kişisel gizlilik ilkesi bağlantısı",
    "Header logo" : "Üst bilgi logosu",
    "Upload new header logo" : "Yeni üst bilgi logosu yükle",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Yeni favicon yükle",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Yüklenen logo ve renge göre otomatik olarak favicon üretilmesi için Imagemagick PHP eklentisini SVG desteği ile kurun."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/theming/l10n/tr.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ön izleme yükleniyor …",
    "Admin" : "Yönetici",
    "Saved" : "Kaydedildi",
    "a safe home for all your data" : "verileriniz için güvenli bir barınak",
    "Error uploading the file" : "Dosya yüklenirken sorun çıktı",
    "Name cannot be empty" : "Ad boş olamaz",
    "The given name is too long" : "Belirtilen ad çok uzun",
    "The given web address is too long" : "Belirtilen web adresi çok uzun",
    "The given web address is not a valid URL" : "Belirtilen web adresi geçersiz",
    "The given legal notice address is too long" : "Belirtilen yasal bildirim adresi çok uzun",
    "The given legal notice address is not a valid URL" : "Belirtilen yasal bildirim adresi geçersiz",
    "The given privacy policy address is too long" : "Belirtilen kişisel gizliliğin korunması ilkesi adresi çok uzun",
    "The given privacy policy address is not a valid URL" : "Belirtilen gizlilik ilkesi adresi geçersiz",
    "The given slogan is too long" : "Belirtilen slogan çok uzun",
    "The given color is invalid" : "Belirtilen renk geçersiz",
    "The file was uploaded" : "Dosya yüklendi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklenen dosya php.ini dosyasındaki yüklenebilecek dosya boyutunu belirten upload_max_filesize değişkeninin değerini aşıyor",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenen dosya HTML formundaki yüklenebilecek dosya boyutunu belirten MAX_FILE_SIZE değişkeninin değerini aşıyor",
    "The file was only partially uploaded" : "Dosyanın yalnızca bir bölümü yüklendi",
    "No file was uploaded" : "Herhangi bir dosya yüklenmedi",
    "Missing a temporary folder" : "Geçici klasör bulunamadı",
    "Could not write file to disk" : "Dosya diske yazılamadı",
    "A PHP extension stopped the file upload" : "Bir PHP eklentisi dosyanın yüklenmesini engelledi",
    "No file uploaded" : "Henüz bir dosya yüklenmemiş",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Zaten özel bir tema kullanıyorsunuz. Tema uygulaması ayarları bu değer ile değiştirilebilir.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Görünüm ve erişilebilirlik",
    "Dark theme with high contrast mode" : "Koyu tema ve yüksek renk karşıtlığı kipi",
    "Enable dark high contrast mode" : "Koyu yüksek renk karşıtlığı kipi kullanılsın",
    "Similar to the high contrast mode, but with dark colours." : "Yüksek renk karşıtlığı kipine benzer ancak koyu renkleri kullanır.",
    "Dark theme" : "Koyu tema",
    "Enable dark theme" : "Koyu tema kullanılsın",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Koyu tema genel aydınlık ve parlaklığı azaltarak gözlerinizi dinlendirir.",
    "System default theme" : "Varsayılan sistem teması",
    "Enable the system default" : "Sistem varsayılanı kullanılsın",
    "Using the default system appearance." : "Varsayılan sistem görünümü kullanılıyor.",
    "Dyslexia font" : "Disleksik yazı türü",
    "Enable dyslexia font" : "Disleksik yazı türü kullanılsın",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic, disleksi nedeniyle sık karşılaşılan sorunları aşmak için geliştirilmiş ücretsiz bir yazı türüdür.",
    "High contrast mode" : "Yüksek renk karşıtlığı kipi",
    "Enable high contrast mode" : "Yüksek renk karşıtlığı kipi kullanılsın",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Yüksek renk karşıtlığı kipi gezinmeyi kolaylaştırır. Görsel kalite azalır ancak netlik artar.",
    "Light theme" : "Açık tema",
    "Enable the default light theme" : "Varsayılan açık tema kullanılsın",
    "The default light appearance." : "Varsayılan açık renkli görünüm.",
    "Legal notice" : "Yasal bildirim",
    "Privacy policy" : "Kişisel gizliliğin korunması ilkesi",
    "Adjust the Nextcloud theme" : "Nextcloud temasını ayarla",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uygulamalarımızı herkesin kullanabilmesini çok önemsiyoruz. Web standartlarını izleyerek, işlemlerin fare olmadan da yapılabilmesini ve ekran okuyucular gibi yardımcı yazılımların kullanılabilmesini sağlıyoruz. AAA düzeyinde yüksek renk karşıtlığı teması ile AA düzeyinde {guidelines}Web İçeriği Erişilebilirlik Kuralları{linkend} 2.1 ile uyumlu olmayı amaçladık.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Bir sorunla karşılaşırsanız, bunları {issuetracker}sorun izleyicimiz{linkend} üzerinden bildirmekten çekinmeyin. Katkıda bulunmak istiyorsanız {designteam}tasarım ekibimize{linkend} katılın!",
    "Theme selection is enforced" : "Tema seçimi zorunludur",
    "Open documentation" : "Belgeleri aç",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Temalar kullandığınız kopyanın ve desteklenen istemcilerin genel görünümün kolayca değiştirilmesini sağlar. Tüm kullanıcılara görüntülenir.",
    "Name" : "Ad",
    "Reset to default" : "Varsayılanlara dön",
    "Web link" : "Web bağlantısı",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Renk",
    "Logo" : "Logo",
    "Upload new logo" : "Yeni logo yükle",
    "Login image" : "Oturum açma görseli",
    "Upload new login background" : "Yeni oturum açma arka planı yükle",
    "Remove background image" : "Arka plan görselini kaldır",
    "Advanced options" : "Gelişmiş ayarlar",
    "Legal notice link" : "Yasal bildirim bağlantısı",
    "Privacy policy link" : "Kişisel gizlilik ilkesi bağlantısı",
    "Header logo" : "Üst bilgi logosu",
    "Upload new header logo" : "Yeni üst bilgi logosu yükle",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Yeni favicon yükle",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Yüklenen logo ve renge göre otomatik olarak favicon üretilmesi için Imagemagick PHP eklentisini SVG desteği ile kurun."
},
"nplurals=2; plural=(n > 1);");
